package http

import (
	"net/http"

	"git.javil.eu/jacob1123/budgeteer/postgres"
	"github.com/gin-gonic/gin"
	"github.com/google/uuid"
)

type AccountsData struct {
	Accounts []postgres.GetAccountsWithBalanceRow
}

func (h *Handler) accounts(c *gin.Context) {
	budgetID := c.Param("budgetid")
	budgetUUID, err := uuid.Parse(budgetID)
	if err != nil {
		c.Redirect(http.StatusTemporaryRedirect, "/login")
		return
	}

	accounts, err := h.Service.DB.GetAccountsWithBalance(c.Request.Context(), budgetUUID)
	if err != nil {
		c.AbortWithError(http.StatusInternalServerError, err)
		return
	}

	d := AccountsData{
		Accounts: accounts,
	}

	c.HTML(http.StatusOK, "accounts.html", d)
}

type AccountData struct {
	Account      *postgres.Account
	Transactions []postgres.Transaction
}

func (h *Handler) account(c *gin.Context) {
	accountID := c.Param("accountid")
	accountUUID, err := uuid.Parse(accountID)
	if err != nil {
		c.Redirect(http.StatusTemporaryRedirect, "/login")
		return
	}

	account, err := h.Service.DB.GetAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	transactions, err := h.Service.DB.GetTransactionsForAccount(c.Request.Context(), accountUUID)
	if err != nil {
		c.AbortWithError(http.StatusNotFound, err)
		return
	}

	d := AccountData{
		Account:      &account,
		Transactions: transactions,
	}

	c.HTML(http.StatusOK, "budget.html", d)
}
